@@ -1,38 +1,24 @@
 /*
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "hwaddrcombobox.h"
 
-#include <NetworkManagerQt/Manager>
-#include <NetworkManagerQt/WiredDevice>
-#include <NetworkManagerQt/WirelessDevice>
 #include <NetworkManagerQt/BluetoothDevice>
-#include <NetworkManagerQt/OlpcMeshDevice>
-#include <NetworkManagerQt/InfinibandDevice>
 #include <NetworkManagerQt/BondDevice>
 #include <NetworkManagerQt/BridgeDevice>
-#include <NetworkManagerQt/VlanDevice>
+#include <NetworkManagerQt/InfinibandDevice>
+#include <NetworkManagerQt/Manager>
+#include <NetworkManagerQt/OlpcMeshDevice>
 #include <NetworkManagerQt/Utils>
+#include <NetworkManagerQt/VlanDevice>
+#include <NetworkManagerQt/WiredDevice>
+#include <NetworkManagerQt/WirelessDevice>
 
-HwAddrComboBox::HwAddrComboBox(QWidget *parent) :
-    QComboBox(parent), m_dirty(false)
+HwAddrComboBox::HwAddrComboBox(QWidget *parent)
+    : QComboBox(parent)
 {
     setEditable(true);
     setInsertPolicy(QComboBox::NoInsert);
@@ -58,7 +44,7 @@ QString HwAddrComboBox::hwAddress() const
     else
         result = currentText();
 
-    // qCDebug(PLASMA_NM)() << "Result:" << currentIndex() << result;
+    // qCDebug(PLASMA_NM_EDITOR_LOG)() << "Result:" << currentIndex() << result;
 
     return result;
 }
@@ -75,11 +61,11 @@ void HwAddrComboBox::slotCurrentIndexChanged(int)
     Q_EMIT hwAddressChanged();
 }
 
-void HwAddrComboBox::init(const NetworkManager::Device::Type &deviceType, const QString &address)
+void HwAddrComboBox::init(NetworkManager::Device::Type deviceType, const QString &address)
 {
     m_initialAddress = address;
 
-    // qCDebug(PLASMA_NM) << "Initial address:" << m_initialAddress;
+    // qCDebug(PLASMA_NM_EDITOR_LOG) << "Initial address:" << m_initialAddress;
 
     QString deviceName;
     for (const NetworkManager::Device::Ptr &device : NetworkManager::networkInterfaces()) {
@@ -99,7 +85,7 @@ void HwAddrComboBox::init(const NetworkManager::Device::Type &deviceType, const
     const int index = findData(m_initialAddress);
     if (index == -1) {
         if (!m_initialAddress.isEmpty()) {
-            const QString text = QStringLiteral("%1 (%2)").arg(deviceName).arg(m_initialAddress);
+            const QString text = QStringLiteral("%1 (%2)").arg(deviceName, m_initialAddress);
             insertItem(0, text, m_initialAddress);
         } else {
             insertItem(0, m_initialAddress, m_initialAddress);
@@ -113,7 +99,7 @@ void HwAddrComboBox::init(const NetworkManager::Device::Type &deviceType, const
 void HwAddrComboBox::addAddressToCombo(const NetworkManager::Device::Ptr &device)
 {
     const QVariant data = hwAddressFromDevice(device);
-    // qCDebug(PLASMA_NM) << "Data:" << data;
+    // qCDebug(PLASMA_NM_EDITOR_LOG) << "Data:" << data;
 
     QString name;
     if (device->state() == NetworkManager::Device::Activated)
@@ -121,20 +107,18 @@ void HwAddrComboBox::addAddressToCombo(const NetworkManager::Device::Ptr &device
     else
         name = device->interfaceName();
 
-    // qCDebug(PLASMA_NM) << "Name:" << name;
+    // qCDebug(PLASMA_NM_EDITOR_LOG) << "Name:" << name;
 
     if (!data.isNull()) {
         if (name == data.toString()) {
             addItem(data.toString(), data);
-        }
-        else {
-            addItem(QStringLiteral("%1 (%2)").arg(name).arg(data.toString()), data);
+        } else {
+            addItem(QStringLiteral("%1 (%2)").arg(name, data.toString()), data);
         }
     }
 }
 
-
-QVariant HwAddrComboBox::hwAddressFromDevice(const NetworkManager::Device::Ptr& device)
+QVariant HwAddrComboBox::hwAddressFromDevice(const NetworkManager::Device::Ptr &device)
 {
     const NetworkManager::Device::Type type = device->type();
 
